Class CommitSpecifierInput
-
- All Implemented Interfaces:
public final class CommitSpecifierInput
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommitSpecifierInput.BuilderA builder for CommitSpecifierInput.
public final classCommitSpecifierInput.PresentationGroupValuesIf provided, the specifier will apply to product usage with these set of presentation group values.
public final classCommitSpecifierInput.PricingGroupValuesIf provided, the specifier will apply to product usage with these set of pricing group values.
-
Method Summary
Modifier and Type Method Description final Optional<CommitSpecifierInput.PresentationGroupValues>presentationGroupValues()If provided, the specifier will apply to product usage with these set of presentation group values. final Optional<CommitSpecifierInput.PricingGroupValues>pricingGroupValues()If provided, the specifier will apply to product usage with these set of pricing group values. final Optional<String>productId()If provided, the specifier will only apply to the product with the specified ID. final Optional<List<String>>productTags()If provided, the specifier will only apply to products with all the specified tags. final JsonField<CommitSpecifierInput.PresentationGroupValues>_presentationGroupValues()Returns the raw JSON value of presentationGroupValues. final JsonField<CommitSpecifierInput.PricingGroupValues>_pricingGroupValues()Returns the raw JSON value of pricingGroupValues. final JsonField<String>_productId()Returns the raw JSON value of productId. final JsonField<List<String>>_productTags()Returns the raw JSON value of productTags. final Map<String, JsonValue>_additionalProperties()final CommitSpecifierInput.BuildertoBuilder()final CommitSpecifierInputvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CommitSpecifierInput.Builderbuilder()Returns a mutable builder for constructing an instance of CommitSpecifierInput. -
-
Method Detail
-
presentationGroupValues
final Optional<CommitSpecifierInput.PresentationGroupValues> presentationGroupValues()
If provided, the specifier will apply to product usage with these set of presentation group values.
-
pricingGroupValues
final Optional<CommitSpecifierInput.PricingGroupValues> pricingGroupValues()
If provided, the specifier will apply to product usage with these set of pricing group values.
-
productId
final Optional<String> productId()
If provided, the specifier will only apply to the product with the specified ID.
-
productTags
final Optional<List<String>> productTags()
If provided, the specifier will only apply to products with all the specified tags.
-
_presentationGroupValues
final JsonField<CommitSpecifierInput.PresentationGroupValues> _presentationGroupValues()
Returns the raw JSON value of presentationGroupValues.
Unlike presentationGroupValues, this method doesn't throw if the JSON field has an unexpected type.
-
_pricingGroupValues
final JsonField<CommitSpecifierInput.PricingGroupValues> _pricingGroupValues()
Returns the raw JSON value of pricingGroupValues.
Unlike pricingGroupValues, this method doesn't throw if the JSON field has an unexpected type.
-
_productId
final JsonField<String> _productId()
Returns the raw JSON value of productId.
Unlike productId, this method doesn't throw if the JSON field has an unexpected type.
-
_productTags
final JsonField<List<String>> _productTags()
Returns the raw JSON value of productTags.
Unlike productTags, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CommitSpecifierInput.Builder toBuilder()
-
validate
final CommitSpecifierInput validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CommitSpecifierInput.Builder builder()
Returns a mutable builder for constructing an instance of CommitSpecifierInput.
-
-
-
-