Package com.metronome.api.models
Class CommitSpecifierInput.PresentationGroupValues
-
- All Implemented Interfaces:
public final class CommitSpecifierInput.PresentationGroupValuesIf provided, the specifier will apply to product usage with these set of presentation group values.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommitSpecifierInput.PresentationGroupValues.BuilderA builder for PresentationGroupValues.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final CommitSpecifierInput.PresentationGroupValues.BuildertoBuilder()final CommitSpecifierInput.PresentationGroupValuesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CommitSpecifierInput.PresentationGroupValues.Builderbuilder()Returns a mutable builder for constructing an instance of PresentationGroupValues. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CommitSpecifierInput.PresentationGroupValues.Builder toBuilder()
-
validate
final CommitSpecifierInput.PresentationGroupValues validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CommitSpecifierInput.PresentationGroupValues.Builder builder()
Returns a mutable builder for constructing an instance of PresentationGroupValues.
-
-
-
-