Class RecurringCommitSubscriptionConfig
-
- All Implemented Interfaces:
public final class RecurringCommitSubscriptionConfig
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRecurringCommitSubscriptionConfig.BuilderA builder for RecurringCommitSubscriptionConfig.
public final classRecurringCommitSubscriptionConfig.Allocationpublic final classRecurringCommitSubscriptionConfig.ApplySeatIncreaseConfig
-
Method Summary
-
-
Method Detail
-
allocation
final RecurringCommitSubscriptionConfig.Allocation allocation()
-
applySeatIncreaseConfig
final RecurringCommitSubscriptionConfig.ApplySeatIncreaseConfig applySeatIncreaseConfig()
-
subscriptionId
final String subscriptionId()
-
_allocation
final JsonField<RecurringCommitSubscriptionConfig.Allocation> _allocation()
Returns the raw JSON value of allocation.
Unlike allocation, this method doesn't throw if the JSON field has an unexpected type.
-
_applySeatIncreaseConfig
final JsonField<RecurringCommitSubscriptionConfig.ApplySeatIncreaseConfig> _applySeatIncreaseConfig()
Returns the raw JSON value of applySeatIncreaseConfig.
Unlike applySeatIncreaseConfig, this method doesn't throw if the JSON field has an unexpected type.
-
_subscriptionId
final JsonField<String> _subscriptionId()
Returns the raw JSON value of subscriptionId.
Unlike subscriptionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RecurringCommitSubscriptionConfig.Builder toBuilder()
-
validate
final RecurringCommitSubscriptionConfig validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RecurringCommitSubscriptionConfig.Builder builder()
Returns a mutable builder for constructing an instance of RecurringCommitSubscriptionConfig.
The following fields are required:
.allocation() .applySeatIncreaseConfig() .subscriptionId()
-
-
-
-